@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import html
 import inspect
-import pprint
+import os
 import traceback
 import typing
 
@@ -13,6 +13,7 @@ if typing.TYPE_CHECKING:
     from .responses import HttpResponse
 
 from .responses import HTMLResponse, PlainTextResponse
+from .utils import F
 
 STYLES = """
 :root {
@@ -21,11 +22,15 @@ STYLES = """
 * {
     box-sizing: border-box;
 }
+body {
+    margin: 0 auto;
+    padding: 0 3em;
+    min-height: calc(100vh - 3em + 1px);
+}
 code, pre, .code {
     font-family: "Biaodian Pro Sans CNS", Menlo, Consolas, Courier, "Zhuyin Heiti", "Han Heiti", monospace;
 }
 .traceback-container {
-    max-width: 1000px;
     border: 3px solid #038BB8;
 }
 .traceback-title {
@@ -85,8 +90,9 @@ table {
     border-spacing: 0px;
     padding: 0 10px;
 }
-table pre {
+table pre.value {
     white-space: pre-wrap;
+    word-break: break-all;
 }
 table tr {
     max-width: 100%;
@@ -108,12 +114,15 @@ TEMPLATE = """
         </style>
         <title>Index.py Debugger</title>
     </head>
-    <body style="max-width: 1000px; margin: 0 auto 3em; min-height: calc(100vh - 3em + 1px);">
+    <body>
         <h1>500 Server Error</h1>
         <div class="traceback-container">
             <p class="traceback-title">{error}</p>
             <div>{exc_html}</div>
         </div>
+        <div class="environs">
+            {environs}
+        </div>
     </body>
 </html>
 """
@@ -132,14 +141,48 @@ FRAME_TEMPLATE = """
 </div>
 """
 
-VARS = """
-<table>
+LOCAL_VARS = """
+<table class="local-vars">
     <tbody>
         {vars}
     </tbody>
 </table>
 """
 
+ENVIRON_VARS = """
+<table class="environ-vars">
+    <thead>
+        <tr>
+            <td>
+                <strong>OS Environ</strong>
+            </td>
+        </tr>
+        <tr>
+            <td>
+                <strong>Name</strong>
+            </td>
+            <td>
+                <strong>Value</strong>
+            </td>
+        </tr>
+    </thead>
+    <tbody>
+        {vars}
+    </tbody>
+</table>
+"""
+
+VAR = """
+<tr>
+    <td>
+        <pre class="name">{name}</pre>
+    </td>
+    <td>
+        <pre class="value">{value}</pre>
+    </td>
+</tr>
+"""
+
 LINE = """
 <p><span class="frame-line code">
 <span class="lineno">{lineno}.</span> {line}</span></p>
@@ -152,20 +195,8 @@ CENTER_LINE = """
 
 
 class DebugMiddleware:
-    """
-    Handles returning 500 responses when a server error occurs.
-
-    If 'debug' is set, then traceback responses will be returned,
-    otherwise the designated 'handler' will be called.
-
-    This middleware class should generally be used to wrap *everything*
-    else up, so that unhandled exceptions anywhere in the stack
-    always result in an appropriate 500 response.
-    """
-
-    def __init__(self, app: ASGIApp, debug: bool = False) -> None:
+    def __init__(self, app: ASGIApp) -> None:
         self.app = app
-        self.debug = debug
 
     async def __call__(self, scope: Scope, receive: Receive, send: Send) -> None:
         if scope["type"] != "http":
@@ -186,10 +217,7 @@ class DebugMiddleware:
         except Exception as exc:
             if not response_started:
                 request = scope["app"].factory_class.http(scope)
-                if self.debug:
-                    response = self.debug_response(request, exc)
-                else:
-                    response = self.error_response(request, exc)
+                response = self.debug_response(request, exc)
                 await response(scope, receive, send)
 
             raise exc
@@ -213,15 +241,14 @@ class DebugMiddleware:
             for index, line in enumerate(frame.code_context or [])
         )
         _locals_vars = frame.frame.f_locals.copy()
-        locals_var = VARS.format(
-            vars="".join(
-                [
-                    "<tr><td><pre>{name}</pre></td><td><pre>{value}</pre></td></tr>".format(
-                        name=name, value=html.escape(pprint.pformat(value))
-                    )
+        locals_var = LOCAL_VARS.format(
+            vars=(
+                (
+                    VAR.format(name=name, value=html.escape(format(value)))
                     for name, value in _locals_vars.items()
-                ]
-            ),
+                )
+                | F("".join)
+            )
         )
 
         values = {
@@ -250,10 +277,18 @@ class DebugMiddleware:
                 exc_html += self.generate_frame_html(frame, is_collapsed)
                 is_collapsed = True
 
-        # escape error class and text
         error = f"{html.escape(traceback_obj.exc_type.__name__)}: {html.escape(str(traceback_obj))}"
 
-        return TEMPLATE.format(styles=STYLES, error=error, exc_html=exc_html)
+        environs = ENVIRON_VARS.format(
+            vars="".join(
+                VAR.format(name=name, value=html.escape(value))
+                for name, value in os.environ.items()
+            )
+        )
+
+        return TEMPLATE.format(
+            styles=STYLES, error=error, exc_html=exc_html, environs=environs
+        )
 
     def generate_plain_text(self, exc: Exception) -> str:
         return "".join(traceback.format_tb(exc.__traceback__))
@@ -262,8 +297,6 @@ class DebugMiddleware:
         if request.accepts("text/html"):
             content = self.generate_html(exc)
             return HTMLResponse(content, status_code=500)
-        content = self.generate_plain_text(exc)
-        return PlainTextResponse(content, status_code=500)
-
-    def error_response(self, request: HttpRequest, exc: Exception) -> HttpResponse:
-        return PlainTextResponse("Internal Server Error", status_code=500)
+        else:
+            content = self.generate_plain_text(exc)
+            return PlainTextResponse(content, status_code=500)
