@@ -1,4 +1,6 @@
-from starlette.datastructures import UploadFile as _UploadFile
+from __future__ import annotations
+
+from baize.formparsers import UploadFile as _UploadFile
 
 
 class UploadFile(_UploadFile):
